@@ -20,12 +20,14 @@ import shutil
 import tempfile
 import uuid
 
+import daiquiri
 import numpy
-import six
 
 from gnocchi import incoming
 from gnocchi import utils
 
+LOG = daiquiri.getLogger(__name__)
+
 
 class FileStorage(incoming.IncomingDriver):
     def __init__(self, conf, greedy=True):
@@ -49,19 +51,17 @@ class FileStorage(incoming.IncomingDriver):
         data = {self.CFG_SACKS: num_sacks}
         with open(os.path.join(self.basepath_tmp, self.CFG_PREFIX), 'w') as f:
             json.dump(data, f)
-        utils.ensure_paths([self._sack_path(i)
-                            for i in six.moves.range(self.NUM_SACKS)])
+        utils.ensure_paths((self._sack_path(s) for s in self.iter_sacks()))
 
-    def remove_sack_group(self, num_sacks):
-        prefix = self.get_sack_prefix(num_sacks)
-        for i in six.moves.xrange(num_sacks):
-            shutil.rmtree(os.path.join(self.basepath, prefix % i))
+    def remove_sacks(self):
+        for sack in self.iter_sacks():
+            shutil.rmtree(os.path.join(self.basepath, str(sack)))
 
     def _sack_path(self, sack):
-        return os.path.join(self.basepath, self.get_sack_name(sack))
+        return os.path.join(self.basepath, str(sack))
 
     def _measure_path(self, sack, metric_id):
-        return os.path.join(self._sack_path(sack), six.text_type(metric_id))
+        return os.path.join(self._sack_path(sack), str(metric_id))
 
     def _build_measure_path(self, metric_id, random_id=None):
         sack = self.sack_for_metric(metric_id)
@@ -69,7 +69,7 @@ class FileStorage(incoming.IncomingDriver):
         if random_id:
             if random_id is True:
                 now = datetime.datetime.utcnow().strftime("_%Y%m%d_%H:%M:%S")
-                random_id = six.text_type(uuid.uuid4()) + now
+                random_id = str(uuid.uuid4()) + now
             return os.path.join(path, random_id)
         return path
 
@@ -108,18 +108,15 @@ class FileStorage(incoming.IncomingDriver):
                 report_vars['measures'] += len(
                     self._list_measures_container_for_metric_str(sack, metric))
 
-        for i in six.moves.range(self.NUM_SACKS):
-            for metric in self.list_metric_with_measures_to_process(i):
-                build_metric_report(metric, i)
+        for sack in self.iter_sacks():
+            for metric in set(self._list_target(self._sack_path(sack))):
+                build_metric_report(metric, sack)
         return (report_vars['metrics'] or
                 len(report_vars['metric_details'].keys()),
                 report_vars['measures'] or
                 sum(report_vars['metric_details'].values()),
                 report_vars['metric_details'] if details else None)
 
-    def list_metric_with_measures_to_process(self, sack):
-        return set(self._list_target(self._sack_path(sack)))
-
     def _list_measures_container_for_metric_str(self, sack, metric_id):
         return self._list_target(self._measure_path(sack, metric_id))
 
@@ -163,15 +160,48 @@ class FileStorage(incoming.IncomingDriver):
         return os.path.isdir(self._build_measure_path(metric_id))
 
     @contextlib.contextmanager
-    def process_measure_for_metric(self, metric_id):
-        files = self._list_measures_container_for_metric(metric_id)
-        measures = self._make_measures_array()
-        for f in files:
-            abspath = self._build_measure_path(metric_id, f)
-            with open(abspath, "rb") as e:
-                measures = numpy.concatenate((
-                    measures, self._unserialize_measures(f, e.read())))
+    def process_measure_for_metrics(self, metric_ids):
+        measures = {}
+        processed_files = {}
+        for metric_id in metric_ids:
+            files = self._list_measures_container_for_metric(metric_id)
+            processed_files[metric_id] = files
+            m = self._make_measures_array()
+            for f in files:
+                abspath = self._build_measure_path(metric_id, f)
+                with open(abspath, "rb") as e:
+                    m = numpy.concatenate((
+                        m, self._unserialize_measures(f, e.read())))
+            measures[metric_id] = m
 
         yield measures
 
-        self._delete_measures_files_for_metric(metric_id, files)
+        for metric_id, files in processed_files.items():
+            self._delete_measures_files_for_metric(metric_id, files)
+
+    @contextlib.contextmanager
+    def process_measures_for_sack(self, sack):
+        measures = {}
+        processed_files = {}
+        for metric_id in self._list_target(self._sack_path(sack)):
+            try:
+                metric_id = uuid.UUID(metric_id)
+            except ValueError:
+                LOG.error("Unable to parse %s as an UUID, ignoring metric",
+                          metric_id)
+                continue
+            files = self._list_measures_container_for_metric_str(
+                sack, metric_id)
+            processed_files[metric_id] = files
+            m = self._make_measures_array()
+            for f in files:
+                abspath = self._build_measure_path(metric_id, f)
+                with open(abspath, "rb") as e:
+                    m = numpy.concatenate((
+                        m, self._unserialize_measures(f, e.read())))
+            measures[metric_id] = m
+
+        yield measures
+
+        for metric_id, files in processed_files.items():
+            self._delete_measures_files_for_metric(metric_id, files)
