@@ -13,12 +13,11 @@
 # under the License.
 from collections import defaultdict
 import contextlib
+import daiquiri
 import datetime
 import json
 import uuid
 
-import six
-
 from gnocchi.common import swift
 from gnocchi import incoming
 from gnocchi import utils
@@ -26,6 +25,8 @@ from gnocchi import utils
 swclient = swift.swclient
 swift_utils = swift.swift_utils
 
+LOG = daiquiri.getLogger(__name__)
+
 
 class SwiftStorage(incoming.IncomingDriver):
     # NOTE(sileht): Using threads with swiftclient doesn't work
@@ -47,73 +48,97 @@ class SwiftStorage(incoming.IncomingDriver):
         self.swift.put_container(self.CFG_PREFIX)
         self.swift.put_object(self.CFG_PREFIX, self.CFG_PREFIX,
                               json.dumps({self.CFG_SACKS: num_sacks}))
-        for i in six.moves.range(num_sacks):
-            self.swift.put_container(self.get_sack_name(i))
+        for sack in self.iter_sacks():
+            self.swift.put_container(str(sack))
 
-    def remove_sack_group(self, num_sacks):
-        prefix = self.get_sack_prefix(num_sacks)
-        for i in six.moves.xrange(num_sacks):
-            self.swift.delete_container(prefix % i)
+    def remove_sacks(self):
+        for sack in self.iter_sacks():
+            self.swift.delete_container(str(sack))
 
     def _store_new_measures(self, metric_id, data):
         now = datetime.datetime.utcnow().strftime("_%Y%m%d_%H:%M:%S")
         self.swift.put_object(
-            self.get_sack_name(self.sack_for_metric(metric_id)),
-            six.text_type(metric_id) + "/" + six.text_type(uuid.uuid4()) + now,
+            str(self.sack_for_metric(metric_id)),
+            str(metric_id) + "/" + str(uuid.uuid4()) + now,
             data)
 
     def _build_report(self, details):
         metric_details = defaultdict(int)
         nb_metrics = 0
         measures = 0
-        for i in six.moves.range(self.NUM_SACKS):
+        for sack in self.iter_sacks():
             if details:
                 headers, files = self.swift.get_container(
-                    self.get_sack_name(i), full_listing=True)
+                    str(sack), full_listing=True)
                 for f in files:
                     metric, __ = f['name'].split("/", 1)
                     metric_details[metric] += 1
             else:
                 headers, files = self.swift.get_container(
-                    self.get_sack_name(i), delimiter='/', full_listing=True)
+                    str(sack), delimiter='/', full_listing=True)
                 nb_metrics += len([f for f in files if 'subdir' in f])
             measures += int(headers.get('x-container-object-count'))
         return (nb_metrics or len(metric_details), measures,
                 metric_details if details else None)
 
-    def list_metric_with_measures_to_process(self, sack):
-        headers, files = self.swift.get_container(
-            self.get_sack_name(sack), delimiter='/', full_listing=True)
-        return set(f['subdir'][:-1] for f in files if 'subdir' in f)
-
     def _list_measure_files_for_metric(self, sack, metric_id):
         headers, files = self.swift.get_container(
-            self.get_sack_name(sack), path=six.text_type(metric_id),
+            str(sack), path=str(metric_id),
             full_listing=True)
         return files
 
     def delete_unprocessed_measures_for_metric(self, metric_id):
         sack = self.sack_for_metric(metric_id)
         files = self._list_measure_files_for_metric(sack, metric_id)
-        swift.bulk_delete(self.swift, self.get_sack_name(sack), files)
+        swift.bulk_delete(self.swift, str(sack), files)
 
     def has_unprocessed(self, metric_id):
         sack = self.sack_for_metric(metric_id)
         return bool(self._list_measure_files_for_metric(sack, metric_id))
 
     @contextlib.contextmanager
-    def process_measure_for_metric(self, metric_id):
-        sack = self.sack_for_metric(metric_id)
-        sack_name = self.get_sack_name(sack)
-        files = self._list_measure_files_for_metric(sack, metric_id)
+    def process_measure_for_metrics(self, metric_ids):
+        measures = {}
+        all_files = defaultdict(list)
+        for metric_id in metric_ids:
+            sack = self.sack_for_metric(metric_id)
+            sack_name = str(sack)
+            files = self._list_measure_files_for_metric(sack, metric_id)
+            all_files[sack_name].extend(files)
+            measures[metric_id] = self._array_concatenate([
+                self._unserialize_measures(
+                    f['name'],
+                    self.swift.get_object(sack_name, f['name'])[1],
+                )
+                for f in files
+            ])
 
-        yield self._array_concatenate([
-            self._unserialize_measures(
-                f['name'],
-                self.swift.get_object(sack_name, f['name'])[1],
-            )
-            for f in files
-        ])
+        yield measures
 
         # Now clean objects
+        for sack_name, files in all_files.items():
+            swift.bulk_delete(self.swift, sack_name, files)
+
+    @contextlib.contextmanager
+    def process_measures_for_sack(self, sack):
+        measures = defaultdict(self._make_measures_array)
+        sack_name = str(sack)
+        headers, files = self.swift.get_container(sack_name, full_listing=True)
+        for f in files:
+            try:
+                metric_id, random_id = f['name'].split("/")
+                metric_id = uuid.UUID(metric_id)
+            except ValueError:
+                LOG.warning("Unable to parse measure file name %s", f)
+                continue
+            measures[metric_id] = self._array_concatenate([
+                measures[metric_id],
+                self._unserialize_measures(
+                    metric_id,
+                    self.swift.get_object(sack_name, f['name'])[1],
+                )
+            ])
+
+        yield measures
+
         swift.bulk_delete(self.swift, sack_name, files)
