@@ -22,6 +22,7 @@ from oslo_config import cfg
 import gnocchi.archive_policy
 import gnocchi.common.redis
 import gnocchi.indexer
+import gnocchi.rest.http_proxy_to_wsgi
 import gnocchi.storage
 import gnocchi.storage.ceph
 import gnocchi.storage.file
@@ -171,6 +172,11 @@ def list_opts():
                        "value may improve worker utilization but may also "
                        "increase load on coordination backend. Value is "
                        "capped by number of workers globally."),
+            cfg.IntOpt('cleanup_batch_size',
+                       default=10000,
+                       min=1,
+                       help="Number of metrics that should be deleted "
+                       "simultaneously by one janitor."),
         )),
         ("api", (
             cfg.StrOpt('paste_config',
@@ -192,7 +198,7 @@ def list_opts():
                        default=10, min=0,
                        help='Number of seconds before timeout when attempting '
                             'to do some operations.'),
-        ) + API_OPTS,
+        ) + API_OPTS + gnocchi.rest.http_proxy_to_wsgi.OPTS,
         ),
         ("storage", _STORAGE_OPTS),
         ("incoming", _INCOMING_OPTS),
@@ -218,6 +224,22 @@ def list_opts():
                 default=10,
                 help='Delay between flushes'),
         )),
+        ("amqp1d", (
+            cfg.StrOpt('url',
+                       default='localhost:5672/u/collectd/telemetry',
+                       help='AMQP 1.0 URL to listen to'),
+            cfg.StrOpt('data_source',
+                       default='collectd',
+                       choices=['collectd'],
+                       help='Data source for amqp1d'),
+            cfg.StrOpt('resource_type',
+                       default='collectd_amqp1d',
+                       help='Resource type name to use to identify metrics'),
+            cfg.StrOpt('creator', help='Creator value to use to amqpd1'),
+            cfg.FloatOpt('flush_delay',
+                         default=10,
+                         help='Delay between flushes in seconds'),
+        )),
         ("archive_policy", gnocchi.archive_policy.OPTS),
     ]
 
