@@ -118,8 +118,15 @@ class KeystoneAuthHelper(object):
 class BasicAuthHelper(object):
     @staticmethod
     def get_current_user(request):
-        auth = werkzeug.http.parse_authorization_header(
-            request.headers.get("Authorization"))
+        hdr = request.headers.get("Authorization")
+        auth_hdr = (hdr.decode('utf-8') if isinstance(hdr, bytes)
+                    else hdr)
+
+        try:
+            auth = werkzeug.http.parse_authorization_header(auth_hdr)
+        except AttributeError:
+            auth = werkzeug.datastructures.Authorization.from_header(auth_hdr)
+
         if auth is None:
             api.abort(401)
         return auth.username
@@ -131,7 +138,8 @@ class BasicAuthHelper(object):
             roles.append("admin")
         return {
             "user": user,
-            "roles": roles
+            "roles": roles,
+            "system": 'all',
         }
 
     @staticmethod
@@ -158,7 +166,8 @@ class RemoteUserAuthHelper(object):
             roles.append("admin")
         return {
             "user": user,
-            "roles": roles
+            "roles": roles,
+            "system": 'all',
         }
 
     @staticmethod
