@@ -16,9 +16,8 @@
 import datetime
 import uuid
 
-import mock
 import numpy
-import six.moves
+from unittest import mock
 
 from gnocchi import archive_policy
 from gnocchi import carbonara
@@ -31,6 +30,7 @@ from gnocchi.storage import redis
 from gnocchi.storage import s3
 from gnocchi.storage import swift
 from gnocchi.tests import base as tests_base
+from gnocchi.tests.test_utils import get_measures_list
 
 
 def datetime64(*args):
@@ -153,10 +153,11 @@ class TestStorageDriver(tests_base.TestCase):
                             side_effect=carbonara.InvalidData()):
                 self.trigger_processing()
 
-        m = self.storage.get_measures(
-            self.metric,
-            self.metric.archive_policy.get_aggregations_for_method('mean'),
-        )['mean']
+        m = self.storage.get_aggregated_measures(
+            {self.metric:
+                self.metric.archive_policy.get_aggregations_for_method(
+                    'mean')},)[self.metric]
+        m = get_measures_list(m)['mean']
         self.assertIn((datetime64(2014, 1, 1),
                        numpy.timedelta64(1, 'D'), 1), m)
         self.assertIn((datetime64(2014, 1, 1, 13),
@@ -183,7 +184,9 @@ class TestStorageDriver(tests_base.TestCase):
             self.metric.archive_policy.get_aggregations_for_method("mean")
         )
 
-        m = self.storage.get_measures(self.metric, aggregations)['mean']
+        m = self.storage.get_aggregated_measures(
+            {self.metric: aggregations})[self.metric]
+        m = get_measures_list(m)['mean']
         self.assertIn((datetime64(2014, 1, 1),
                        numpy.timedelta64(1, 'D'), 5.0), m)
         self.assertIn((datetime64(2014, 1, 1, 12),
@@ -204,11 +207,12 @@ class TestStorageDriver(tests_base.TestCase):
         )
 
         self.assertRaises(storage.MetricDoesNotExist,
-                          self.storage.get_measures,
-                          self.metric, aggregations)
+                          self.storage.get_aggregated_measures,
+                          {self.metric: aggregations})
         self.assertEqual(
             {self.metric: None},
-            self.storage._get_or_create_unaggregated_timeseries([self.metric]))
+            self.storage._get_or_create_unaggregated_timeseries(
+                [self.metric]))
 
     def test_measures_reporting_format(self):
         report = self.incoming.measures_report(True)
@@ -227,7 +231,7 @@ class TestStorageDriver(tests_base.TestCase):
 
     def test_measures_reporting(self):
         m2, __ = self._create_metric('medium')
-        for i in six.moves.range(60):
+        for i in range(60):
             self.incoming.add_measures(self.metric.id, [
                 incoming.Measure(datetime64(2014, 1, 1, 12, 0, i), 69),
             ])
@@ -248,7 +252,7 @@ class TestStorageDriver(tests_base.TestCase):
     def test_get_aggregated_measures(self):
         self.incoming.add_measures(self.metric.id, [
             incoming.Measure(datetime64(2014, 1, 1, 12, i, j), 100)
-            for i in six.moves.range(0, 60) for j in six.moves.range(0, 60)])
+            for i in range(0, 60) for j in range(0, 60)])
         self.trigger_processing([self.metric])
 
         aggregations = self.metric.archive_policy.aggregations
@@ -266,11 +270,11 @@ class TestStorageDriver(tests_base.TestCase):
     def test_get_aggregated_measures_multiple(self):
         self.incoming.add_measures(self.metric.id, [
             incoming.Measure(datetime64(2014, 1, 1, 12, i, j), 100)
-            for i in six.moves.range(0, 60) for j in six.moves.range(0, 60)])
+            for i in range(0, 60) for j in range(0, 60)])
         m2, __ = self._create_metric('medium')
         self.incoming.add_measures(m2.id, [
             incoming.Measure(datetime64(2014, 1, 1, 12, i, j), 100)
-            for i in six.moves.range(0, 60) for j in six.moves.range(0, 60)])
+            for i in range(0, 60) for j in range(0, 60)])
         self.trigger_processing([self.metric, m2])
 
         aggregations = self.metric.archive_policy.aggregations
@@ -295,7 +299,7 @@ class TestStorageDriver(tests_base.TestCase):
         m, __ = self._create_metric('high')
         self.incoming.add_measures(m.id, [
             incoming.Measure(datetime64(2014, 1, 1, 12, i, j), 100)
-            for i in six.moves.range(0, 60) for j in six.moves.range(0, 60)])
+            for i in range(0, 60) for j in range(0, 60)])
         self.trigger_processing([m])
 
         aggregations = (
@@ -303,14 +307,15 @@ class TestStorageDriver(tests_base.TestCase):
         )
 
         self.assertEqual(3661, len(
-            self.storage.get_measures(m, aggregations)['mean']))
+            get_measures_list(self.storage.get_aggregated_measures(
+                {m: aggregations})[m])['mean']))
 
     @mock.patch('gnocchi.carbonara.SplitKey.POINTS_PER_SPLIT', 48)
     def test_add_measures_update_subset_split(self):
         m, m_sql = self._create_metric('medium')
         measures = [
             incoming.Measure(datetime64(2014, 1, 6, i, j, 0), 100)
-            for i in six.moves.range(2) for j in six.moves.range(0, 60, 2)]
+            for i in range(2) for j in range(0, 60, 2)]
         self.incoming.add_measures(m.id, measures)
         self.trigger_processing([m])
 
@@ -325,7 +330,7 @@ class TestStorageDriver(tests_base.TestCase):
         for call in c.mock_calls:
             # policy is 60 points and split is 48. should only update 2nd half
             args = call[1]
-            for metric, key_agg_data_offset in six.iteritems(args[0]):
+            for metric, key_agg_data_offset in args[0].items():
                 if metric.id == m_sql.id:
                     for key, aggregation, data, offset in key_agg_data_offset:
                         if (key.sampling == numpy.timedelta64(1, 'm')
@@ -337,7 +342,7 @@ class TestStorageDriver(tests_base.TestCase):
         m, m_sql = self._create_metric('medium')
         measures = [
             incoming.Measure(datetime64(2014, 1, 6, i, j, 0), 100)
-            for i in six.moves.range(2) for j in six.moves.range(0, 60, 2)]
+            for i in range(2) for j in range(0, 60, 2)]
         self.incoming.add_measures(m.id, measures)
         self.trigger_processing([m])
 
@@ -371,7 +376,8 @@ class TestStorageDriver(tests_base.TestCase):
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(5, 'm'), 69.0),
             (datetime64(2014, 1, 1, 12, 5), numpy.timedelta64(5, 'm'), 23.0),
             (datetime64(2014, 1, 1, 12, 10), numpy.timedelta64(5, 'm'), 44.0),
-        ]}, self.storage.get_measures(self.metric, aggregations))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: aggregations})[self.metric]))
 
         # One year later…
         self.incoming.add_measures(self.metric.id, [
@@ -383,7 +389,8 @@ class TestStorageDriver(tests_base.TestCase):
             (datetime64(2015, 1, 1), numpy.timedelta64(1, 'D'), 69),
             (datetime64(2015, 1, 1, 12), numpy.timedelta64(1, 'h'), 69),
             (datetime64(2015, 1, 1, 12), numpy.timedelta64(5, 'm'), 69),
-        ]}, self.storage.get_measures(self.metric, aggregations))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: aggregations})[self.metric]))
 
         agg = self.metric.archive_policy.get_aggregation(
             "mean", numpy.timedelta64(1, 'D'))
@@ -570,7 +577,8 @@ class TestStorageDriver(tests_base.TestCase):
             (datetime64(2016, 1, 2, 13, 7), numpy.timedelta64(1, 'm'), 42),
             (datetime64(2016, 1, 4, 14, 9), numpy.timedelta64(1, 'm'), 4),
             (datetime64(2016, 1, 6, 15, 12), numpy.timedelta64(1, 'm'), 44),
-        ]}, self.storage.get_measures(self.metric, [aggregation]))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: [aggregation]})[self.metric]))
 
         # Now store brand new points that should force a rewrite of one of the
         # split (keep in mind the back window size in one hour here). We move
@@ -637,7 +645,8 @@ class TestStorageDriver(tests_base.TestCase):
             (datetime64(2016, 1, 6, 15, 12), numpy.timedelta64(1, 'm'), 44),
             (datetime64(2016, 1, 10, 16, 18), numpy.timedelta64(1, 'm'), 45),
             (datetime64(2016, 1, 10, 17, 12), numpy.timedelta64(1, 'm'), 46),
-        ]}, self.storage.get_measures(self.metric, [aggregation]))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: [aggregation]})[self.metric]))
 
     def test_rewrite_measures_multiple_granularities(self):
         apname = str(uuid.uuid4())
@@ -737,7 +746,8 @@ class TestStorageDriver(tests_base.TestCase):
             (datetime64(2016, 1, 2, 13, 7), numpy.timedelta64(1, 'm'), 42),
             (datetime64(2016, 1, 4, 14, 9), numpy.timedelta64(1, 'm'), 4),
             (datetime64(2016, 1, 6, 15, 12), numpy.timedelta64(1, 'm'), 44),
-        ]}, self.storage.get_measures(self.metric, [aggregation]))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: [aggregation]})[self.metric]))
 
         # Now store brand new points that should force a rewrite of one of the
         # split (keep in mind the back window size is one hour here). We move
@@ -804,7 +814,8 @@ class TestStorageDriver(tests_base.TestCase):
             (datetime64(2016, 1, 4, 14, 9), numpy.timedelta64(1, 'm'), 4),
             (datetime64(2016, 1, 6, 15, 12), numpy.timedelta64(1, 'm'), 44),
             (datetime64(2016, 1, 10, 0, 12), numpy.timedelta64(1, 'm'), 45),
-        ]}, self.storage.get_measures(self.metric, [aggregation]))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: [aggregation]})[self.metric]))
 
     def test_rewrite_measures_corruption_missing_file(self):
         # Create an archive policy that spans on several splits. Each split
@@ -880,7 +891,8 @@ class TestStorageDriver(tests_base.TestCase):
              numpy.timedelta64(1, 'm'), 4),
             (datetime64(2016, 1, 6, 15, 12),
              numpy.timedelta64(1, 'm'), 44),
-        ]}, self.storage.get_measures(self.metric, [aggregation]))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: [aggregation]})[self.metric]))
 
         # Test what happens if we delete the latest split and then need to
         # compress it!
@@ -970,7 +982,8 @@ class TestStorageDriver(tests_base.TestCase):
             (datetime64(2016, 1, 2, 13, 7), numpy.timedelta64(1, 'm'), 42),
             (datetime64(2016, 1, 4, 14, 9), numpy.timedelta64(1, 'm'), 4),
             (datetime64(2016, 1, 6, 15, 12), numpy.timedelta64(1, 'm'), 44),
-        ]}, self.storage.get_measures(self.metric, [aggregation]))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: [aggregation]})[self.metric]))
 
         # Test what happens if we write garbage
         self.storage._store_metric_splits({
@@ -1007,7 +1020,8 @@ class TestStorageDriver(tests_base.TestCase):
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(1, 'h'), 55.5),
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(5, 'm'), 69),
             (datetime64(2014, 1, 1, 12, 5), numpy.timedelta64(5, 'm'), 42.0),
-        ]}, self.storage.get_measures(self.metric, aggregations))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: aggregations})[self.metric]))
 
         self.incoming.add_measures(self.metric.id, [
             incoming.Measure(datetime64(2014, 1, 1, 12, 9, 31), 4),
@@ -1021,7 +1035,8 @@ class TestStorageDriver(tests_base.TestCase):
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(5, 'm'), 69.0),
             (datetime64(2014, 1, 1, 12, 5), numpy.timedelta64(5, 'm'), 23.0),
             (datetime64(2014, 1, 1, 12, 10), numpy.timedelta64(5, 'm'), 44.0),
-        ]}, self.storage.get_measures(self.metric, aggregations))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: aggregations})[self.metric]))
 
         aggregations = (
             self.metric.archive_policy.get_aggregations_for_method("max")
@@ -1033,7 +1048,8 @@ class TestStorageDriver(tests_base.TestCase):
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(5, 'm'), 69.0),
             (datetime64(2014, 1, 1, 12, 5), numpy.timedelta64(5, 'm'), 42.0),
             (datetime64(2014, 1, 1, 12, 10), numpy.timedelta64(5, 'm'), 44.0),
-        ]}, self.storage.get_measures(self.metric, aggregations))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: aggregations})[self.metric]))
 
         aggregations = (
             self.metric.archive_policy.get_aggregations_for_method("min")
@@ -1045,7 +1061,8 @@ class TestStorageDriver(tests_base.TestCase):
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(5, 'm'), 69.0),
             (datetime64(2014, 1, 1, 12, 5), numpy.timedelta64(5, 'm'), 4.0),
             (datetime64(2014, 1, 1, 12, 10), numpy.timedelta64(5, 'm'), 44.0),
-        ]}, self.storage.get_measures(self.metric, aggregations))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: aggregations})[self.metric]))
 
     def test_add_and_get_splits(self):
         self.incoming.add_measures(self.metric.id, [
@@ -1066,51 +1083,52 @@ class TestStorageDriver(tests_base.TestCase):
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(5, 'm'), 69.0),
             (datetime64(2014, 1, 1, 12, 5), numpy.timedelta64(5, 'm'), 23.0),
             (datetime64(2014, 1, 1, 12, 10), numpy.timedelta64(5, 'm'), 44.0),
-        ]}, self.storage.get_measures(self.metric, aggregations))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: aggregations})[self.metric]))
 
         self.assertEqual({"mean": [
             (datetime64(2014, 1, 1), numpy.timedelta64(1, 'D'), 39.75),
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(1, 'h'), 39.75),
             (datetime64(2014, 1, 1, 12, 10), numpy.timedelta64(5, 'm'), 44.0),
-        ]}, self.storage.get_measures(
-            self.metric, aggregations,
-            from_timestamp=datetime64(2014, 1, 1, 12, 10, 0)))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: aggregations},
+            from_timestamp=datetime64(2014, 1, 1, 12, 10, 0))[self.metric]))
 
         self.assertEqual({"mean": [
             (datetime64(2014, 1, 1), numpy.timedelta64(1, 'D'), 39.75),
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(1, 'h'), 39.75),
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(5, 'm'), 69.0),
             (datetime64(2014, 1, 1, 12, 5), numpy.timedelta64(5, 'm'), 23.0),
-        ]}, self.storage.get_measures(
-            self.metric, aggregations,
-            to_timestamp=datetime64(2014, 1, 1, 12, 6, 0)))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: aggregations},
+            to_timestamp=datetime64(2014, 1, 1, 12, 6, 0))[self.metric]))
 
         self.assertEqual({"mean": [
             (datetime64(2014, 1, 1), numpy.timedelta64(1, 'D'), 39.75),
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(1, 'h'), 39.75),
             (datetime64(2014, 1, 1, 12, 10), numpy.timedelta64(5, 'm'), 44.0),
-        ]}, self.storage.get_measures(
-            self.metric, aggregations,
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: aggregations},
             to_timestamp=datetime64(2014, 1, 1, 12, 10, 10),
-            from_timestamp=datetime64(2014, 1, 1, 12, 10, 10)))
+            from_timestamp=datetime64(2014, 1, 1, 12, 10, 10))[self.metric]))
 
         self.assertEqual({"mean": [
             (datetime64(2014, 1, 1), numpy.timedelta64(1, 'D'), 39.75),
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(1, 'h'), 39.75),
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(5, 'm'), 69.0),
-        ]}, self.storage.get_measures(
-            self.metric, aggregations,
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: aggregations},
             from_timestamp=datetime64(2014, 1, 1, 12, 0, 0),
-            to_timestamp=datetime64(2014, 1, 1, 12, 0, 2)))
+            to_timestamp=datetime64(2014, 1, 1, 12, 0, 2))[self.metric]))
 
         self.assertEqual({"mean": [
             (datetime64(2014, 1, 1), numpy.timedelta64(1, 'D'), 39.75),
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(1, 'h'), 39.75),
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(5, 'm'), 69.0),
-        ]}, self.storage.get_measures(
-            self.metric, aggregations,
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: aggregations},
             from_timestamp=datetime64(2014, 1, 1, 12),
-            to_timestamp=datetime64(2014, 1, 1, 12, 0, 2)))
+            to_timestamp=datetime64(2014, 1, 1, 12, 0, 2))[self.metric]))
 
         aggregation_1h = (
             self.metric.archive_policy.get_aggregation(
@@ -1119,10 +1137,10 @@ class TestStorageDriver(tests_base.TestCase):
 
         self.assertEqual({"mean": [
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(1, 'h'), 39.75),
-        ]}, self.storage.get_measures(
-            self.metric, [aggregation_1h],
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: [aggregation_1h]},
             from_timestamp=datetime64(2014, 1, 1, 12, 0, 0),
-            to_timestamp=datetime64(2014, 1, 1, 12, 0, 2)))
+            to_timestamp=datetime64(2014, 1, 1, 12, 0, 2))[self.metric]))
 
         aggregation_5m = (
             self.metric.archive_policy.get_aggregation(
@@ -1131,16 +1149,18 @@ class TestStorageDriver(tests_base.TestCase):
 
         self.assertEqual({"mean": [
             (datetime64(2014, 1, 1, 12), numpy.timedelta64(5, 'm'), 69.0),
-        ]}, self.storage.get_measures(
-            self.metric, [aggregation_5m],
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {self.metric: [aggregation_5m]},
             from_timestamp=datetime64(2014, 1, 1, 12, 0, 0),
-            to_timestamp=datetime64(2014, 1, 1, 12, 0, 2)))
+            to_timestamp=datetime64(2014, 1, 1, 12, 0, 2))[self.metric]))
 
         self.assertEqual({"mean": []},
-                         self.storage.get_measures(
-                             self.metric,
-                             [carbonara.Aggregation(
-                                 "mean", numpy.timedelta64(42, 's'), None)]))
+                         get_measures_list(
+                             self.storage.get_aggregated_measures(
+                                 {self.metric:
+                                     [carbonara.Aggregation(
+                                         "mean", numpy.timedelta64(42, 's'),
+                                      None)]})[self.metric]))
 
     def test_get_measure_unknown_aggregation(self):
         self.incoming.add_measures(self.metric.id, [
@@ -1156,8 +1176,8 @@ class TestStorageDriver(tests_base.TestCase):
 
         self.assertRaises(
             storage.MetricDoesNotExist,
-            self.storage.get_measures,
-            self.metric, aggregations)
+            self.storage.get_aggregated_measures,
+            {self.metric: aggregations})
 
     def test_resize_policy(self):
         name = str(uuid.uuid4())
@@ -1179,7 +1199,8 @@ class TestStorageDriver(tests_base.TestCase):
             (datetime64(2014, 1, 1, 12, 0, 0), numpy.timedelta64(5, 's'), 1),
             (datetime64(2014, 1, 1, 12, 0, 5), numpy.timedelta64(5, 's'), 1),
             (datetime64(2014, 1, 1, 12, 0, 10), numpy.timedelta64(5, 's'), 1),
-        ]}, self.storage.get_measures(m, [aggregation]))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {m: [aggregation]})[m]))
         # expand to more points
         self.index.update_archive_policy(
             name, [archive_policy.ArchivePolicyItem(granularity=5, points=6)])
@@ -1192,7 +1213,8 @@ class TestStorageDriver(tests_base.TestCase):
             (datetime64(2014, 1, 1, 12, 0, 5), numpy.timedelta64(5, 's'), 1),
             (datetime64(2014, 1, 1, 12, 0, 10), numpy.timedelta64(5, 's'), 1),
             (datetime64(2014, 1, 1, 12, 0, 15), numpy.timedelta64(5, 's'), 1),
-        ]}, self.storage.get_measures(m, [aggregation]))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {m: [aggregation]})[m]))
         # shrink timespan
         self.index.update_archive_policy(
             name, [archive_policy.ArchivePolicyItem(granularity=5, points=2)])
@@ -1202,16 +1224,17 @@ class TestStorageDriver(tests_base.TestCase):
         self.assertEqual({"mean": [
             (datetime64(2014, 1, 1, 12, 0, 10), numpy.timedelta64(5, 's'), 1),
             (datetime64(2014, 1, 1, 12, 0, 15), numpy.timedelta64(5, 's'), 1),
-        ]}, self.storage.get_measures(m, [aggregation]))
+        ]}, get_measures_list(self.storage.get_aggregated_measures(
+            {m: [aggregation]})[m]))
 
     def test_resample_no_metric(self):
         """https://github.com/gnocchixyz/gnocchi/issues/69"""
         aggregation = self.metric.archive_policy.get_aggregation(
             "mean", numpy.timedelta64(300, 's'))
         self.assertRaises(storage.MetricDoesNotExist,
-                          self.storage.get_measures,
-                          self.metric,
-                          [aggregation],
+                          self.storage.get_aggregated_measures,
+                          {self.metric:
+                              [aggregation]},
                           datetime64(2014, 1, 1),
                           datetime64(2015, 1, 1),
                           resample=numpy.timedelta64(1, 'h'))
